@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """
 test_abort_generate_on_hook_error.
 
@@ -18,7 +16,7 @@ from cookiecutter import exceptions, generate
     ids=("pre_gen_hook_raises_error", "post_gen_hook_raises_error"),
 )
 @pytest.mark.usefixtures("clean_system")
-def test_hooks_raises_errors(tmpdir, abort_pre_gen, abort_post_gen):
+def test_hooks_raises_errors(tmp_path, abort_pre_gen, abort_post_gen):
     """Verify pre- and pos-gen errors raises correct error code from script.
 
     This allows developers to make different error codes in their code,
@@ -34,7 +32,9 @@ def test_hooks_raises_errors(tmpdir, abort_pre_gen, abort_post_gen):
 
     with pytest.raises(exceptions.FailedHookException) as error:
         generate.generate_files(
-            repo_dir="tests/hooks-abort-render", context=context, output_dir=str(tmpdir)
+            repo_dir="tests/hooks-abort-render",
+            context=context,
+            output_dir=str(tmp_path),
         )
         assert error.value.code == 5
-    assert not tmpdir.join("foobar").isdir()
+    assert not tmp_path.joinpath("foobar").is_dir()
