@@ -3,6 +3,7 @@
 Use the global clean_system fixture and run additional teardown code to remove
 some special folders.
 """
+
 from pathlib import Path
 
 import pytest
@@ -11,13 +12,6 @@ from binaryornot.check import is_binary
 from cookiecutter import exceptions, generate
 
 
-@pytest.mark.parametrize('invalid_dirname', ['', '{foo}', '{{foo', 'bar}}'])
-def test_ensure_dir_is_templated_raises(invalid_dirname):
-    """Verify `ensure_dir_is_templated` raises on wrong directories names input."""
-    with pytest.raises(exceptions.NonTemplatedInputDirException):
-        generate.ensure_dir_is_templated(invalid_dirname)
-
-
 def test_generate_files_nontemplated_exception(tmp_path):
     """
     Verify `generate_files` raises when no directories to render exist.
