@@ -4,14 +4,13 @@ tests_output_folder.
 Test formerly known from a unittest residing in test_generate.py named
 TestOutputFolder.test_output_folder
 """
+
 import os
 from pathlib import Path
 
 import pytest
 
-from cookiecutter import exceptions
-from cookiecutter import generate
-from cookiecutter import utils
+from cookiecutter import exceptions, generate, utils
 
 
 @pytest.fixture(scope='function')
